==> speech-analytic-testing_2.2.0_database.tar.gz: database/mssql/procedures/GetEvaluationReviewCommitments.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationReviewCommitments] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	SELECT ER.[EvaluationPlanId]										'evaluationPlanId',
			ERC.[ID]													'id',
			AEP.[Score]													'score',
			ER.[SupervisorId]											'supervisorId',
			CONCAT(U2.[FirstName], ' ', ISNULL(U2.[LastName], ''))		'supervisorName',
			ERC.[LargeInteractionId]									'largeInteractionId',
			ERC.[AgentId]												'agentId',
			CONCAT(U1.[FirstName], ' ', ISNULL(U1.[LastName], ''))		'agentName',
			ERC.[Commitment]											'commitment',
			ERC.[CreatedDate]											'eventDate',
			ERC.[CreatedDate]											'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		INNER JOIN [dbo].[User] U1 (NOLOCK)
			ON U1.[VCC] = ERC.[VCC]
				AND U1.[ID] = ERC.[AgentId]
		INNER JOIN [dbo].[User] U2 (NOLOCK)
			ON U1.[VCC] = ERC.[VCC]
				AND U2.[ID] = ER.[SupervisorId]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			ON AEP.[Instance] = ERC.[VCC]
				AND AEP.[IdEvaluationPlan] = ER.[EvaluationPlanId]
				AND AEP.[IdInteraction] = ER.[InteractionId]
				AND AEP.[IdAuditor] = ER.[SupervisorId]
				AND AEP.[IdAgent] = ERC.[AgentId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] =  ISNULL(@EvaluationPlanId, ER.[EvaluationPlanId])
			AND ER.[InteractionId] = ISNULL(@InteractionId, ER.[InteractionId])
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.2.2_database.tar.gz: database/mssql/procedures/GetEvaluationReviewCommitments.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationReviewCommitments] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	SELECT ERC.[EvaluationPlanId]										'evaluationPlanId',
			ERC.[ID]													'id',
			AEP.[Score]													'score',
			ERC.[SupervisorId]											'supervisorId',
			CONCAT(U2.[FirstName], ' ', ISNULL(U2.[LastName], ''))		'supervisorName',
			ERC.[LargeInteractionId]									'largeInteractionId',
			ERC.[AgentId]												'agentId',
			CONCAT(U1.[FirstName], ' ', ISNULL(U1.[LastName], ''))		'agentName',
			ERC.[Commitment]											'commitment',
			ERC.[CreatedDate]											'eventDate',
			ERC.[CreatedDate]											'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		LEFT JOIN [dbo].[User] U1 (NOLOCK)
			ON U1.[VCC] = ERC.[VCC]
				AND U1.[ID] = ERC.[AgentId]
		INNER JOIN [dbo].[User] U2 (NOLOCK)
			ON U2.[VCC] = ERC.[VCC]
				AND U2.[ID] = ERC.[SupervisorId]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			ON AEP.[Instance] = ERC.[VCC]
				AND AEP.[IdEvaluationPlan] = ERC.[EvaluationPlanId]
				AND AEP.[IdInteraction] = ERC.[InteractionId]
				AND AEP.[IdAuditor] = ERC.[SupervisorId]
				AND AEP.[IdAgent] = ERC.[AgentId]
		WHERE ERC.[VCC] = @VCC
			AND ERC.[EvaluationPlanId] =  ISNULL(@EvaluationPlanId, ERC.[EvaluationPlanId])
			AND ERC.[InteractionId] = ISNULL(@InteractionId, ERC.[InteractionId])
			AND ERC.[SupervisorId] = ISNULL(@SupervisorId, ERC.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
